Alignak Backend import
======================

*Import flat files Nagios-like configuration into the Alignak backend*

Build status (stable release)
----------------------------------------

.. image:: https://travis-ci.org/Alignak-monitoring-contrib/alignak-backend-import.svg?branch=master
    :target: https://travis-ci.org/Alignak-monitoring-contrib/alignak-backend-import

.. image:: https://readthedocs.org/projects/alignak-backend-import/badge/?version=latest
  :target: http://alignak-backend-import.readthedocs.org/en/latest/?badge=latest
  :alt: Documentation Status


Build status (development release)
----------------------------------------

.. image:: https://travis-ci.org/Alignak-monitoring-contrib/alignak-backend-import.svg?branch=develop
    :target: https://travis-ci.org/Alignak-monitoring-contrib/alignak-backend-import

.. image:: https://readthedocs.org/projects/alignak-backend-import/badge/?version=develop
  :target: http://alignak-backend-import.readthedocs.org/en/develop/?badge=develop
  :alt: Documentation Status


Documentation
----------------------------------------

You can find online documentation on `Read The Docs <http://alignak-backend-import.readthedocs.org>`_.

Release strategy
----------------------------------------

Alignak backend and its *satellites* (backend client, and backend import tools) must all have the
same features level. As of it, take care to install the same minor version on your system to
ensure compatibility between all the packages. Use 0.4.x version of Backend import and Backend
client with a 0.4.x version of the Backend.

The current stable version of Alignak backend import is 0.5.1.

Short description
-------------------

This package contains an utility tool `alignak_backend_import` that allows to import a Nagios-like flat files monitoring configuration into an Alignak Backend.

Bugs, issues and contributing
----------------------------------------

Please report any issue using the project `GitHub repository<https://github.com/Alignak-monitoring-contrib/alignak-backend-import/issues>`_.

License
----------------------------------------

Alignak Backend Import is available under the `GPL version 3 <http://opensource.org/licenses/GPL-3.0>`_.

